@@ -110,21 +110,80 @@ class Player:
 
         creep_tumor_count = 0
         for obj in self.objects.values():
-            if obj.status != 'live':
-                continue
-
             # odd tile objects position += 0.5. Rounded off in events
             if obj.name == 'Hatchery' or obj.name == 'Lair' or obj.name == 'Hive':
                 creep_radius = 12
             elif obj.name == 'CreepTumorBurrowed':
-                creep_tumor_count += 1
                 creep_radius = 10
+
+                if obj.status == 'live':
+                    creep_tumor_count += 1
             else:
                 continue
 
             # add 0.5 to get center of central tile
             building_position = (obj.position['x'] + 0.5, obj.position['y'] + 0.5)
 
+            if obj.status == 'died':
+                def remove_tiles(tile_range, current_position):
+                    # always add midpoint in row
+                    try:
+                        self._creep_tiles.remove(current_position)
+                    except KeyError:
+                        pass
+
+                    # if only 1 tile in row, we're done
+                    # else expand horizontally, count new tiles until max radius
+                    # this should never happen with the improved approximation
+                    if tile_range != 0:
+                        for j in range(0, tile_range + 1):
+                            try:
+                                self._creep_tiles.remove((current_position[0] + j, current_position[1]))
+                                self._creep_tiles.remove((current_position[0] - j, current_position[1]))
+                            except KeyError:
+                                continue
+
+                # removing middle row tiles
+                remove_tiles(creep_radius, building_position)
+
+                for i in range(0, creep_radius//2):
+                    row_increment = i + 1
+
+                    # ----- full-size rows -----
+                    # add radius/2 full-size rows to improve area approximation
+                    remove_tiles(
+                        creep_radius,
+                        (building_position[0], building_position[1] + row_increment),
+                    )
+
+                    # tile actions are mirrored in y-axis
+                    remove_tiles(
+                        creep_radius,
+                        (building_position[0], building_position[1] - row_increment),
+                    )
+
+                    # ----- decreasing size rows -----
+                    remove_tiles(
+                        creep_radius - row_increment,
+                        (
+                            building_position[0],
+                            building_position[1] + row_increment + creep_radius/2
+                        ),
+                    )
+
+                    # tile actions are mirrored in y-axis
+                    remove_tiles(
+                        creep_radius - row_increment,
+                        (
+                            building_position[0],
+                            building_position[1] - row_increment - creep_radius/2
+                        ),
+                    )
+                continue
+
+            elif obj.status != 'live':
+                continue
+
             def add_tiles(tile_range, current_position):
                 # always add midpoint in row
                 self._creep_tiles.add(current_position)
